==> cramr_ui_lib-0.0.14.tar.gz: lib/widgets/coverable_textfield.dart <==
import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

/// Stateful widget that allows to show an indicative for a given person, and
/// that allows to cover (default) this indicative.
class CoverableTextField extends StatefulWidget {
  final int person;

  const CoverableTextField({Key? key, required this.person}) : super(key: key);

  @override
  State<CoverableTextField> createState() => CoverableTextFieldState();
}

/// State of the field is about whether it is covered or not.
class CoverableTextFieldState extends State<CoverableTextField> {
  bool _coverStatus = true;

  @override
  Widget build(BuildContext context) {
    return Consumer<VerbTestModel>(builder: (context, testModel, child) {
      return GestureDetector(
        key: Key(
            'cover_gesturedetector_${testModel.verb.infinitive}_${widget.person}'),
        onTap: () {
          setState(() {
            _coverStatus = !_coverStatus;
          });
        },
        child: _coverStatus
            ? Card(
                key: Key(
                    'coverkey_${testModel.verb.infinitive}_${widget.person}'),
                child: SizedBox(
                  height: 40,
                  width: 150,
                  child: Container(
                    key: UniqueKey(),
                    color: Colors.green[400],
                  ),
                ),
                elevation: 15.0,
                shadowColor: Colors.green[600],
              )
            : Card(
                key: Key('$testModel.verb.indicative[$widget.person]'),
                child: SizedBox(
                  height: 40,
                  width: 150,
                  child: Container(
                    key: UniqueKey(),
                    alignment: Alignment.center,
                    child: Text(testModel.verb.indicative[widget.person],
                        key: UniqueKey(),
                        textDirection: TextDirection.ltr,
                        style: const TextStyle(
                          color: Colors.green,
                          fontSize: 25,
                        )),
                  ),
                ),
                elevation: 10.0,
              ),
      );
    });
  }
}

==> cramr_ui_lib-0.0.17.tar.gz: lib/widgets/coverable_textfield.dart <==
import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

/// Stateful widget that allows to show an indicative for a given person, and
/// that allows to cover (default) this indicative.
class CoverableTextField extends StatefulWidget {
  final int person;

  const CoverableTextField({Key? key, required this.person}) : super(key: key);

  @override
  State<CoverableTextField> createState() => CoverableTextFieldState();
}

/// State of the field is about whether it is covered or not.
class CoverableTextFieldState extends State<CoverableTextField> {
  bool _coverStatus = true;

  @override
  Widget build(BuildContext context) {
    return Consumer<VerbTestModel>(builder: (context, testModel, child) {
      return GestureDetector(
        key: Key(
            'cover_gesturedetector_${testModel.verb.infinitive}_${widget.person}'),
        onTap: () {
          setState(() {
            _coverStatus = !_coverStatus;
          });
        },
        child: _coverStatus
            ? Card(
                key: Key(
                    'coverkey_${testModel.verb.infinitive}_${widget.person}'),
                child: SizedBox(
                  height: 40,
                  width: 180,
                  child: Container(
                    key: UniqueKey(),
                    color: Colors.green[400],
                  ),
                ),
                elevation: 15.0,
                shadowColor: Colors.green[600],
              )
            : Card(
                key: Key('$testModel.verb.indicative[$widget.person]'),
                child: SizedBox(
                  height: 40,
                  width: 180,
                  child: Container(
                    key: UniqueKey(),
                    alignment: Alignment.center,
                    child: Text(
                      testModel.verb.indicative[widget.person],
                      key: UniqueKey(),
                      textDirection: TextDirection.ltr,
                      style: const TextStyle(
                        color: Colors.green,
                        fontSize: 25,
                      ),
                      overflow: TextOverflow.ellipsis,
                    ),
                  ),
                ),
                elevation: 10.0,
              ),
      );
    });
  }
}
